package Data::CompactReadonly::V0::Scalar::NegativeHuge;
our $VERSION = '0.1.0';

use warnings;
use strict;
use base qw(
    Data::CompactReadonly::V0::NegativeScalar
    Data::CompactReadonly::V0::Scalar::Huge
);

1;
